#!/usr/bin/env python
import pandas as pd
from abromics_galaxy_json_extractor.interfaces import (
    AbromicsResultIterator,
)

required_metadata = {
    "analysis_software_version": "bandage version number",
    "hid": "historic ID for bandage file from galaxy",
    "bandage_plot_path": "bandage plot file",
    "bandage_plot_hid": "historic ID for bandage plot from galaxy",
}


class BandageIterator(AbromicsResultIterator):
    """Bandage tool parser
    Extract result from Bandage info results
    Args:
        AbromicsResultIterator (abc.ABCMeta): abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "bandage"
        super().__init__(source, metadata)
        self.abromics_results["tool_has_database"] = False
        self.parse()

    def parse(self):
        """Extract information from bandage info"""
        bandage_infos = pd.read_table(self.source, header=None, sep=":")
        bandage_infos[0] = bandage_infos[0].replace(" ", "_", regex=True)
        bandage_infos[1] = bandage_infos[1].replace(" ", "", regex=True)
        bandage_infos = dict(zip(bandage_infos[0], bandage_infos[1]))
        self.abromics_results["results"][0]["content"] = bandage_infos

        {
            self.extract_metadata_information(self.metadata, k, v)
            for k, v in self.metadata.items()
            if "path" in k
        }
